@@ -2,19 +2,9 @@
 
 #include <uuid.h>
 
+#include <stdio.h>
 #include <unistd.h>
-#include <time.h>
-#include <sys/time.h>
-#include <sys/stat.h>
-#include <sys/types.h>
-#include <stdlib.h>
-#include <string.h>
-#include <fcntl.h>
-#include <errno.h>
-#include <string.h>
-#include <sys/file.h>
 #include <sys/ioctl.h>
-#include <sys/socket.h>
 #include <net/if.h>
 #include <netinet/in.h>
 
