@@ -3,6 +3,13 @@
 
 #include <uuid.h>
 
+/* define interface number
+ * 0 is eth0
+ * 1 is eth1
+ * ......
+ */
+#define IF_NUMBER 0
+
 #ifdef __cplusplus
 extern "C" {
 #endif
