@@ -5,7 +5,7 @@
 #include <ctype.h>
 #include <string.h>
 
-int uuid_parse(const char in[], uuid_p uu)
+int uuid_parse(const char in[], uuid_p p)
 {
 	int 		i;
 	const char	*cp;
@@ -27,16 +27,16 @@ int uuid_parse(const char in[], uuid_p uu)
 		if (!isxdigit(*cp))
 			return -1;
 	}
-	uu->time_low = strtoul(in, NULL, 16);
-	uu->time_mid = strtoul(in+9, NULL, 16);
-	uu->time_hi_and_version = strtoul(in+14, NULL, 16);
-	uu->clock_seq = strtoul(in+19, NULL, 16);
+	p->time_low = strtoul(in, NULL, 16);
+	p->time_mid = strtoul(in+9, NULL, 16);
+	p->time_hi_and_version = strtoul(in+14, NULL, 16);
+	p->clock_seq = strtoul(in+19, NULL, 16);
 	cp = in+24;
 	buf[2] = 0;
 	for (i=0; i < 6; i++) {
 		buf[0] = *cp++;
 		buf[1] = *cp++;
-		uu->node[i] = strtoul(buf, NULL, 16);
+		p->node[i] = strtoul(buf, NULL, 16);
 	}
 	
 	return 0;
