@@ -1,10 +1,10 @@
 #include <uuid.h>
 
-int uuid_variant(const uuid_p uptr)
+int uuid_variant(const uuid_p p)
 {
 	int var;
 
-	var = uptr->clock_seq;
+	var = p->clock_seq;
 
 	if ((var & 0x8000) == 0)
 		return UUID_VARIANT_NCS;
